@@ -11,9 +11,11 @@ from sphinx.ext.napoleon.docstring import GoogleDocstring, NumpyDocstring
 from sphinx.util import inspect
 
 if TYPE_CHECKING:
+    from collections.abc import Sequence, Set
     from typing import Any
 
     from sphinx.config import _ConfigRebuild
+    from sphinx.ext.autodoc._property_types import _AutodocObjType
     from sphinx.util.typing import ExtensionMetadata
 
 
@@ -270,27 +272,27 @@ class Config:
 
     """
 
-    _config_values: dict[str, tuple[Any, _ConfigRebuild]] = {
-        'napoleon_google_docstring': (True, 'env'),
-        'napoleon_numpy_docstring': (True, 'env'),
-        'napoleon_include_init_with_doc': (False, 'env'),
-        'napoleon_include_private_with_doc': (False, 'env'),
-        'napoleon_include_special_with_doc': (False, 'env'),
-        'napoleon_use_admonition_for_examples': (False, 'env'),
-        'napoleon_use_admonition_for_notes': (False, 'env'),
-        'napoleon_use_admonition_for_references': (False, 'env'),
-        'napoleon_use_ivar': (False, 'env'),
-        'napoleon_use_param': (True, 'env'),
-        'napoleon_use_rtype': (True, 'env'),
-        'napoleon_use_keyword': (True, 'env'),
-        'napoleon_preprocess_types': (False, 'env'),
-        'napoleon_type_aliases': (None, 'env'),
-        'napoleon_custom_sections': (None, 'env'),
-        'napoleon_attr_annotations': (True, 'env'),
-    }
+    _config_values: Sequence[tuple[str, bool | None, _ConfigRebuild, Set[type]]] = (
+        ('napoleon_google_docstring', True, 'env', frozenset({bool})),
+        ('napoleon_numpy_docstring', True, 'env', frozenset({bool})),
+        ('napoleon_include_init_with_doc', False, 'env', frozenset({bool})),
+        ('napoleon_include_private_with_doc', False, 'env', frozenset({bool})),
+        ('napoleon_include_special_with_doc', False, 'env', frozenset({bool})),
+        ('napoleon_use_admonition_for_examples', False, 'env', frozenset({bool})),
+        ('napoleon_use_admonition_for_notes', False, 'env', frozenset({bool})),
+        ('napoleon_use_admonition_for_references', False, 'env', frozenset({bool})),
+        ('napoleon_use_ivar', False, 'env', frozenset({bool})),
+        ('napoleon_use_param', True, 'env', frozenset({bool})),
+        ('napoleon_use_rtype', True, 'env', frozenset({bool})),
+        ('napoleon_use_keyword', True, 'env', frozenset({bool})),
+        ('napoleon_preprocess_types', False, 'env', frozenset({bool})),
+        ('napoleon_type_aliases', None, 'env', frozenset({dict, NoneType})),
+        ('napoleon_custom_sections', None, 'env', frozenset({list, tuple, NoneType})),
+        ('napoleon_attr_annotations', True, 'env', frozenset({bool})),
+    )
 
     def __init__(self, **settings: Any) -> None:
-        for name, (default, _rebuild) in self._config_values.items():
+        for name, default, _rebuild, _types in self._config_values:
             setattr(self, name, default)
         for name, value in settings.items():
             setattr(self, name, value)
@@ -331,11 +333,9 @@ def setup(app: Sphinx) -> ExtensionMetadata:
     app.connect('autodoc-process-docstring', _process_docstring)
     app.connect('autodoc-skip-member', _skip_member)
 
-    for name, (default, rebuild) in Config._config_values.items():
-        if isinstance(default, bool):
-            app.add_config_value(name, default, rebuild, types=frozenset({bool}))
-        else:
-            app.add_config_value(name, default, rebuild, types=frozenset({NoneType}))
+    for name, default, rebuild, types in Config._config_values:
+        app.add_config_value(name, default, rebuild, types=types)
+
     return {
         'version': sphinx.__display_version__,
         'parallel_read_safe': True,
@@ -363,7 +363,12 @@ def _patch_python_domain() -> None:
 
 
 def _process_docstring(
-    app: Sphinx, what: str, name: str, obj: Any, options: Any, lines: list[str]
+    app: Sphinx,
+    what: _AutodocObjType,
+    name: str,
+    obj: Any,
+    options: Any,
+    lines: list[str],
 ) -> None:
     """Process the docstring for a given python object.
 
@@ -416,7 +421,7 @@ def _process_docstring(
 
 
 def _skip_member(
-    app: Sphinx, what: str, name: str, obj: Any, skip: bool, options: Any
+    app: Sphinx, what: _AutodocObjType, name: str, obj: Any, skip: bool, options: Any
 ) -> bool | None:
     """Determine if private and special class members are included in docs.
 
