@@ -106,6 +106,14 @@ def _decorator(f):
     return wrapper
 
 
+def forward_reference_in_args(x: Foo) -> None:  # type: ignore[name-defined] # noqa: F821
+    pass
+
+
+def forward_reference_in_return() -> Foo:  # type: ignore[name-defined] # noqa: F821
+    pass
+
+
 def test_TypeAliasForwardRef():
     alias = TypeAliasForwardRef('example')
     sig_str = stringify_annotation(alias, 'fully-qualified-except-typing')
@@ -115,6 +123,14 @@ def test_TypeAliasForwardRef():
     sig_str = stringify_annotation(alias, 'fully-qualified-except-typing')
     assert sig_str == "TypeAliasForwardRef('example') | None"
 
+    alias = alias | None
+    sig_str = stringify_annotation(alias, 'fully-qualified-except-typing')
+    assert sig_str == "TypeAliasForwardRef('example') | None"
+
+    alias = None | alias  # NoQA: RUF036
+    sig_str = stringify_annotation(alias, 'fully-qualified-except-typing')
+    assert sig_str == "None | TypeAliasForwardRef('example')"
+
 
 def test_TypeAliasNamespace() -> None:
     import logging.config
@@ -164,6 +180,13 @@ def test_signature() -> None:
     sig = inspect.stringify_signature(inspect.signature(func))
     assert sig == '(a, b, c=1, d=2, *e, **f)'
 
+    # forward references
+    sig = inspect.stringify_signature(inspect.signature(forward_reference_in_args))
+    assert sig == '(x: Foo) -> None'
+
+    sig = inspect.stringify_signature(inspect.signature(forward_reference_in_return))
+    assert sig == '() -> Foo'
+
 
 def test_signature_partial() -> None:
     def fun(a, b, c=1, d=2):
